import { uniqueId } from '../utils/uniqueId.js';
import { getContext, onDestroy, onMount, setContext } from 'svelte';
export function createSideNavigatonStore() {
    let accordionIds = $state([]);
    setContext('SIDE_NAVIGATION', {
        onAccordionMount(accordionId) {
            accordionIds = [...accordionIds, accordionId];
        },
        onAccordionDestroy(accordionId) {
            accordionIds = accordionIds.filter((id) => id !== accordionId);
        }
    });
    return {
        get accordionIds() {
            return accordionIds;
        }
    };
}
export function useAccordion() {
    const id = uniqueId('side-navigation-accordion-');
    const accordionContext = getContext('SIDE_NAVIGATION');
    onMount(() => {
        if (accordionContext?.onAccordionMount) {
            accordionContext.onAccordionMount(id);
        }
    });
    onDestroy(() => {
        if (accordionContext?.onAccordionDestroy) {
            accordionContext.onAccordionDestroy(id);
        }
    });
}
